@@ -1,10 +1,12 @@
 #ifndef QUICKJSR_HPP
 #define QUICKJSR_HPP
 
+#include <quickjsr/JS_SEXP.hpp>
 #include <quickjsr/SEXP_to_JSValue.hpp>
 #include <quickjsr/JSValue_to_SEXP.hpp>
 #include <quickjsr/JSValue_to_JSON.hpp>
 #include <quickjsr/JSON_to_JSValue.hpp>
 #include <quickjsr/type_traits.hpp>
+#include <quickjsr/JS_PropertyRecursive.hpp>
 
 #endif
