@@ -7,23 +7,28 @@
 #include <cpp11.hpp>
 #include <quickjs-libc.h>
 
+#if R_VERSION < R_Version(4, 5, 0)
+# define R_ClosureFormals(x) FORMALS(x)
+# define Rf_isDataFrame(x) Rf_isFrame(x)
+#endif
+
 namespace quickjsr {
   // Forward declaration to allow for recursive calls
   inline JSValue SEXP_to_JSValue(JSContext* ctx, const SEXP& x, bool auto_unbox, bool auto_unbox_curr);
-  inline JSValue SEXP_to_JSValue(JSContext* ctx, const SEXP& x, bool auto_unbox, bool auto_unbox_curr, int index);
+  inline JSValue SEXP_to_JSValue(JSContext* ctx, const SEXP& x, bool auto_unbox, bool auto_unbox_curr, int64_t index);
 
   inline JSValue SEXP_to_JSValue_array(JSContext* ctx, const SEXP& x, bool auto_unbox, bool auto_unbox_curr) {
     JSValue arr = JS_NewArray(ctx);
-    for (int i = 0; i < Rf_length(x); i++) {
+    for (int64_t i = 0; i < Rf_xlength(x); i++) {
       JSValue val = SEXP_to_JSValue(ctx, x, auto_unbox, auto_unbox_curr, i);
-      JS_SetPropertyUint32(ctx, arr, i, val);
+      JS_SetPropertyInt64(ctx, arr, i, val);
     }
     return arr;
   }
 
   inline JSValue SEXP_to_JSValue_object(JSContext* ctx, const SEXP& x, bool auto_unbox, bool auto_unbox_curr) {
     JSValue obj = JS_NewObject(ctx);
-    for (int i = 0; i < Rf_length(x); i++) {
+    for (int64_t i = 0; i < Rf_xlength(x); i++) {
       JSValue val = SEXP_to_JSValue(ctx, x, auto_unbox, auto_unbox_curr, i);
       SEXP name = STRING_ELT(Rf_getAttrib(x, R_NamesSymbol), i);
       JS_SetPropertyStr(ctx, obj, Rf_translateCharUTF8(name), val);
@@ -41,21 +46,20 @@ namespace quickjsr {
     }
   }
 
-  // For a dataframe with the first column of type list and the second column of type data.frame
   inline JSValue SEXP_to_JSValue_df(JSContext* ctx, const SEXP& x, bool auto_unbox_inp = false, bool auto_unbox = false) {
     SEXP col_names = Rf_getAttrib(x, R_NamesSymbol);
     SEXP row_names = Rf_getAttrib(x, R_RowNamesSymbol);
     JSValue arr = JS_NewArray(ctx);
 
-    for (int i = 0; i < Rf_length(VECTOR_ELT(x, 0)); i++) {
+    for (int64_t i = 0; i < Rf_xlength(VECTOR_ELT(x, 0)); i++) {
       JSValue obj = JS_NewObject(ctx);
 
-      for (int j = 0; j < Rf_length(x); j++) {
+      for (int64_t j = 0; j < Rf_xlength(x); j++) {
         SEXP col = VECTOR_ELT(x, j);
-        if (Rf_isFrame(col)) {
+        if (Rf_isDataFrame(col)) {
           JSValue df_obj = JS_NewObject(ctx);
           SEXP df_names = Rf_getAttrib(col, R_NamesSymbol);
-          for (int k = 0; k < Rf_length(col); k++) {
+          for (int64_t k = 0; k < Rf_xlength(col); k++) {
             JSValue val = SEXP_to_JSValue(ctx, VECTOR_ELT(col, k), auto_unbox_inp, auto_unbox, i);
             JS_SetPropertyStr(ctx, df_obj, Rf_translateCharUTF8(STRING_ELT(df_names, k)), val);
           }
@@ -72,7 +76,7 @@ namespace quickjsr {
         JS_SetPropertyStr(ctx, obj, "_row", row_name);
       }
 
-      JS_SetPropertyUint32(ctx, arr, i, obj);
+      JS_SetPropertyInt64(ctx, arr, i, obj);
     }
 
     return arr;
@@ -99,7 +103,7 @@ namespace quickjsr {
                                           bool auto_unbox = false) {
     JSValue obj = JS_NewObjectClass(ctx, js_sexp_class_id);
     JS_SetOpaque(obj, reinterpret_cast<void*>(x));
-    return JS_NewCFunctionData(ctx, js_fun_static, Rf_length(FORMALS(x)),
+    return JS_NewCFunctionData(ctx, js_fun_static, Rf_xlength(R_ClosureFormals(x)),
                                 JS_CFUNC_generic, 1, &obj);
   }
 
@@ -111,22 +115,22 @@ namespace quickjsr {
 
 
   inline JSValue SEXP_to_JSValue_matrix(JSContext* ctx, const SEXP& x, bool auto_unbox_inp = false, bool auto_unbox = false) {
-    int nrow = Rf_nrows(x);
-    int ncol = Rf_ncols(x);
+    int64_t nrow = Rf_nrows(x);
+    int64_t ncol = Rf_ncols(x);
     JSValue arr = JS_NewArray(ctx);
-    for (int i = 0; i < nrow; i++) {
+    for (int64_t i = 0; i < nrow; i++) {
       JSValue row = JS_NewArray(ctx);
-      for (int j = 0; j < ncol; j++) {
+      for (int64_t j = 0; j < ncol; j++) {
         JSValue val = SEXP_to_JSValue(ctx, x, auto_unbox_inp, auto_unbox, i + j * nrow);
-        JS_SetPropertyUint32(ctx, row, j, val);
+        JS_SetPropertyInt64(ctx, row, j, val);
       }
-      JS_SetPropertyUint32(ctx, arr, i, row);
+      JS_SetPropertyInt64(ctx, arr, i, row);
     }
     return arr;
   }
 
-  inline JSValue SEXP_to_JSValue(JSContext* ctx, const SEXP& x, bool auto_unbox, bool auto_unbox_curr, int index) {
-    if (Rf_isFrame(x)) {
+  inline JSValue SEXP_to_JSValue(JSContext* ctx, const SEXP& x, bool auto_unbox, bool auto_unbox_curr, int64_t index) {
+    if (Rf_isDataFrame(x)) {
       return SEXP_to_JSValue_df(ctx, VECTOR_ELT(x, index), auto_unbox, auto_unbox_curr);
     }
     if (Rf_isNewList(x)) {
@@ -145,9 +149,12 @@ namespace quickjsr {
       }
       case REALSXP: {
         if (Rf_inherits(x, "POSIXct")) {
-          return JS_NewDate(ctx, REAL_ELT(x, index), true);
+          static constexpr double milliseconds_second = 1000;
+          double tz_offset_seconds = get_tz_offset_seconds();
+          return JS_NewDate(ctx, (REAL_ELT(x, index) + tz_offset_seconds) * milliseconds_second);
         } else if (Rf_inherits(x, "Date")) {
-          return JS_NewDate(ctx, REAL_ELT(x, index));
+          static constexpr double milliseconds_day = 86400000;
+          return JS_NewDate(ctx, REAL_ELT(x, index) * milliseconds_day);
         } else {
           return JS_NewFloat64(ctx, REAL_ELT(x, index));
         }
@@ -172,7 +179,7 @@ namespace quickjsr {
                           bool auto_unbox_inp = false,
                           bool auto_unbox = false) {
     bool auto_unbox_curr = static_cast<bool>(Rf_inherits(x, "AsIs")) ? false : auto_unbox_inp;
-    if (Rf_isFrame(x)) {
+    if (Rf_isDataFrame(x)) {
       return SEXP_to_JSValue_df(ctx, x, auto_unbox_inp, auto_unbox_curr);
     }
     if (Rf_isNewList(x)) {
@@ -182,7 +189,7 @@ namespace quickjsr {
       return SEXP_to_JSValue_matrix(ctx, x, auto_unbox_inp, auto_unbox_curr);
     }
     if (Rf_isVectorAtomic(x) || Rf_isArray(x)) {
-      if (Rf_length(x) > 1 || !auto_unbox_curr || Rf_isArray(x)) {
+      if (Rf_xlength(x) > 1 || !auto_unbox_curr || Rf_isArray(x)) {
         return SEXP_to_JSValue_array(ctx, x, auto_unbox_inp, auto_unbox_curr);
       }
     }
